@@ -37,7 +37,7 @@
  *     and its possible pointer constraint (using #MetaPointerConstraint)
  * - Setting the cursor sprite (using #MetaCursorRenderer)
  * - Interacting with logind (using the appropriate D-Bus interface)
- * - Querying logind (over D-Bus) to know when the lid is closed
+ * - Querying UPower (over D-Bus) to know when the lid is closed
  * - Setup Remote Desktop / Screencasting (#MetaRemoteDesktop)
  * - Setup the #MetaEgl object
  *
@@ -196,8 +196,8 @@ struct _MetaBackendPrivate
   MetaPointerConstraint *client_pointer_constraint;
   MetaDnd *dnd;
 
-  guint logind_watch_id;
-  GDBusProxy *logind_proxy;
+  guint upower_watch_id;
+  GDBusProxy *upower_proxy;
   gboolean lid_is_closed;
   gboolean on_battery;
 
@@ -290,8 +290,9 @@ meta_backend_finalize (GObject *object)
       priv->sleep_signal_id = 0;
     }
   g_clear_object (&priv->system_bus);
-  g_clear_handle_id (&priv->logind_watch_id, g_bus_unwatch_name);
-  g_clear_object (&priv->logind_proxy);
+
+  g_clear_handle_id (&priv->upower_watch_id, g_bus_unwatch_name);
+  g_clear_object (&priv->upower_proxy);
 
   g_clear_object (&priv->settings);
  #ifdef HAVE_EGL
@@ -708,7 +709,7 @@ meta_backend_is_headless (MetaBackend *backend)
 }
 
 static void
-logind_properties_changed (GDBusProxy *proxy,
+upower_properties_changed (GDBusProxy *proxy,
                            GVariant   *changed_properties,
                            GStrv       invalidated_properties,
                            gpointer    user_data)
@@ -719,7 +720,7 @@ logind_properties_changed (GDBusProxy *proxy,
   gboolean reset_idle_time = FALSE;
 
   v = g_variant_lookup_value (changed_properties,
-                              "LidClosed",
+                              "LidIsClosed",
                               G_VARIANT_TYPE_BOOLEAN);
   if (v)
     {
@@ -740,13 +741,13 @@ logind_properties_changed (GDBusProxy *proxy,
     }
 
   v = g_variant_lookup_value (changed_properties,
-                              "OnExternalPower",
+                              "OnBattery",
                               G_VARIANT_TYPE_BOOLEAN);
   if (v)
     {
       gboolean on_battery;
 
-      on_battery = !g_variant_get_boolean (v);
+      on_battery = g_variant_get_boolean (v);
       g_variant_unref (v);
 
       if (on_battery != priv->on_battery)
@@ -761,7 +762,7 @@ logind_properties_changed (GDBusProxy *proxy,
 }
 
 static void
-logind_ready_cb (GObject      *source_object,
+upower_ready_cb (GObject      *source_object,
                  GAsyncResult *res,
                  gpointer      user_data)
 {
@@ -775,7 +776,7 @@ logind_ready_cb (GObject      *source_object,
   if (!proxy)
     {
       if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        g_warning ("Failed to create logind proxy: %s", error->message);
+        g_warning ("Failed to create UPower proxy: %s", error->message);
       g_error_free (error);
       return;
     }
@@ -783,11 +784,11 @@ logind_ready_cb (GObject      *source_object,
   backend = META_BACKEND (user_data);
   priv = meta_backend_get_instance_private (backend);
 
-  priv->logind_proxy = proxy;
+  priv->upower_proxy = proxy;
   g_signal_connect (proxy, "g-properties-changed",
-                    G_CALLBACK (logind_properties_changed), backend);
+                    G_CALLBACK (upower_properties_changed), backend);
 
-  v = g_dbus_proxy_get_cached_property (proxy, "LidClosed");
+  v = g_dbus_proxy_get_cached_property (proxy, "LidIsClosed");
   if (v)
     {
       priv->lid_is_closed = g_variant_get_boolean (v);
@@ -800,16 +801,16 @@ logind_ready_cb (GObject      *source_object,
         }
     }
 
-  v = g_dbus_proxy_get_cached_property (proxy, "OnExternalPower");
+  v = g_dbus_proxy_get_cached_property (proxy, "OnBattery");
   if (v)
     {
-      priv->on_battery = !g_variant_get_boolean (v);
+      priv->on_battery = g_variant_get_boolean (v);
       g_variant_unref (v);
     }
 }
 
 static void
-logind_appeared (GDBusConnection *connection,
+upower_appeared (GDBusConnection *connection,
                  const gchar     *name,
                  const gchar     *name_owner,
                  gpointer         user_data)
@@ -820,23 +821,23 @@ logind_appeared (GDBusConnection *connection,
   g_dbus_proxy_new (connection,
                     G_DBUS_PROXY_FLAGS_NONE,
                     NULL,
-                    "org.freedesktop.login1",
-                    "/org/freedesktop/login1",
-                    "org.freedesktop.login1.Manager",
+                    "org.freedesktop.UPower",
+                    "/org/freedesktop/UPower",
+                    "org.freedesktop.UPower",
                     priv->cancellable,
-                    logind_ready_cb,
+                    upower_ready_cb,
                     backend);
 }
 
 static void
-logind_vanished (GDBusConnection *connection,
+upower_vanished (GDBusConnection *connection,
                  const gchar     *name,
                  gpointer         user_data)
 {
   MetaBackend *backend = META_BACKEND (user_data);
   MetaBackendPrivate *priv = meta_backend_get_instance_private (backend);
 
-  g_clear_object (&priv->logind_proxy);
+  g_clear_object (&priv->upower_proxy);
 }
 
 static void
@@ -1358,11 +1359,11 @@ meta_backend_initable_init (GInitable     *initable,
   if (META_BACKEND_GET_CLASS (backend)->is_lid_closed ==
       meta_backend_real_is_lid_closed)
     {
-      priv->logind_watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
-                                                "org.freedesktop.login1",
+      priv->upower_watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
+                                                "org.freedesktop.UPower",
                                                 G_BUS_NAME_WATCHER_FLAGS_NONE,
-                                                logind_appeared,
-                                                logind_vanished,
+                                                upower_appeared,
+                                                upower_vanished,
                                                 backend,
                                                 NULL);
     }
@@ -1417,8 +1418,6 @@ meta_backend_initable_init (GInitable     *initable,
 
   meta_monitor_manager_setup (priv->monitor_manager);
 
-  meta_backend_update_stage (backend);
-
   priv->remote_access_controller =
     meta_remote_access_controller_new ();
 
